
From: Sam Ravnborg <sam@ravnborg.org>

List all entries in arch/$(ARCH)/configs/*_defconfig when doing 'make
help'.

Results in output like this (ppc64 as example):

  g5_defconfig             - Build for g5
  pSeries_defconfig        - Build for pSeries

The implementation is generic and enables this for all users of _defconfig.


---

 25-akpm/Makefile |    8 ++++++++
 1 files changed, 8 insertions(+)

diff -puN Makefile~kbuild-add-defconfig-targets-to-make-help Makefile
--- 25/Makefile~kbuild-add-defconfig-targets-to-make-help	Wed Feb 25 14:02:02 2004
+++ 25-akpm/Makefile	Wed Feb 25 14:02:02 2004
@@ -890,6 +890,9 @@ rpm:	clean spec
 # Brief documentation of the typical targets used
 # ---------------------------------------------------------------------------
 
+boards := $(wildcard $(srctree)/arch/$(ARCH)/configs/*_defconfig)
+boards := $(notdir $(boards))
+
 help:
 	@echo  'Cleaning targets:'
 	@echo  '  clean		  - remove most generated files but keep the config'
@@ -915,6 +918,11 @@ help:
 	@$(if $(archhelp),$(archhelp),\
 		echo '  No architecture specific help defined for $(ARCH)')
 	@echo  ''
+	@$(if $(boards), \
+		$(foreach b, $(boards), \
+		printf "  %-24s - Build for %s\\n" $(b) $(subst _defconfig,,$(b));) \
+		echo '')
+
 	@echo  '  make V=0|1 [targets] 0 => quiet build (default), 1 => verbose build'
 	@echo  '  make O=dir [targets] Locate all output files in "dir", including .config'
 	@echo  '  make C=1   [targets] Check all c source with checker tool'

_
